@@ -1,14 +1,14 @@
 """
 Routines for rendering a Splitgraph repository as a tree of images
 """
-from collections import defaultdict, OrderedDict
+from collections import OrderedDict, defaultdict
 from datetime import datetime
 from typing import TYPE_CHECKING, List
 
 import click
 
-from splitgraph.commandline.common import Color
 from splitgraph.config import SG_CMD_ASCII
+from splitgraph.core.output import Color
 
 if TYPE_CHECKING:
     from splitgraph.core.repository import Repository
@@ -57,6 +57,7 @@ def render_tree(repository: "Repository") -> None:
     """Draws the repository's commit graph as a Git-like tree."""
 
     import asciitree
+
     from splitgraph.core.output import truncate_line
 
     # Get all commits in ascending time order
