@@ -1,11 +1,17 @@
+import itertools
 import re
 import threading
 from abc import ABC
 from contextlib import contextmanager
-from typing import Any, Iterator, List, Optional, Sequence, Tuple, Union, cast
+from typing import Any, Dict, Iterator, List, Optional, Sequence, Tuple, Union, cast
 
 from psycopg2.sql import SQL, Composed, Identifier
 
+from splitgraph.core.overlay import (
+    WRITE_LOWER_PREFIX,
+    WRITE_MERGED_PREFIX,
+    WRITE_UPPER_PREFIX,
+)
 from splitgraph.core.types import TableColumn, TableSchema
 from splitgraph.engine import ResultShape
 
@@ -134,22 +140,42 @@ class SQLEngine(ABC):
         target_schema: str,
         target_table: str,
         with_pk_constraints: bool = True,
+        cursor_fields: Optional[Dict[str, str]] = None,
     ) -> None:
         """Copy a table in the same engine, optionally applying primary key constraints as well."""
 
+        if cursor_fields:
+            where_clause = (
+                SQL(" WHERE (")
+                + SQL(",").join(map(Identifier, cursor_fields))
+                + SQL(") > (")
+                + SQL(",").join(itertools.repeat(SQL("%s"), len(cursor_fields)))
+                + SQL(")")
+            )
+            query_args = list(cursor_fields.values())
+        else:
+            where_clause = SQL("")
+            query_args = []
+
         if not self.table_exists(target_schema, target_table):
-            query = SQL("CREATE TABLE {}.{} AS SELECT * FROM {}.{}").format(
-                Identifier(target_schema),
-                Identifier(target_table),
-                Identifier(source_schema),
-                Identifier(source_table),
+            query = (
+                SQL("CREATE TABLE {}.{} AS SELECT * FROM {}.{}").format(
+                    Identifier(target_schema),
+                    Identifier(target_table),
+                    Identifier(source_schema),
+                    Identifier(source_table),
+                )
+                + where_clause
             )
         else:
-            query = SQL("INSERT INTO {}.{} SELECT * FROM {}.{}").format(
-                Identifier(target_schema),
-                Identifier(target_table),
-                Identifier(source_schema),
-                Identifier(source_table),
+            query = (
+                SQL("INSERT INTO {}.{} SELECT * FROM {}.{}").format(
+                    Identifier(target_schema),
+                    Identifier(target_table),
+                    Identifier(source_schema),
+                    Identifier(source_table),
+                )
+                + where_clause
             )
         pks = self.get_primary_keys(source_schema, source_table)
 
@@ -161,7 +187,7 @@ class SQLEngine(ABC):
                 + SQL(",").join(SQL("{}").format(Identifier(c)) for c, _ in pks)
                 + SQL(")")
             )
-        self.run_sql(query)
+        self.run_sql(query, query_args)
 
     def delete_table(self, schema: str, table: str) -> None:
         """Drop a table from a schema if it exists"""
@@ -193,19 +219,31 @@ class SQLEngine(ABC):
             return_shape=ResultShape.NONE,
         )
 
-    def get_all_tables(self, schema: str) -> List[str]:
-        """Get all tables in a given schema."""
+    def get_all_tables(self, schema: str, include_overlay_components: bool = False) -> List[str]:
+        """
+        Get all tables in a given schema.
+
+        :param schema: Schema to fetch the table from.
+        :param include_overlay_components: Controls whether to return upper and lower tables of on a overlay view.
+        """
+        query = SQL("SELECT table_name FROM information_schema.tables WHERE table_schema = %s")
+        args = [schema]
+
+        if not include_overlay_components:
+            query += SQL(" AND table_name NOT LIKE ALL (ARRAY[%s, %s, %s])")
+            args += [
+                WRITE_LOWER_PREFIX + "%",
+                WRITE_UPPER_PREFIX + "%",
+                WRITE_MERGED_PREFIX + "%",
+            ]
+
         return cast(
             List[str],
-            self.run_sql(
-                "SELECT table_name FROM information_schema.tables WHERE table_schema = %s",
-                (schema,),
-                return_shape=ResultShape.MANY_ONE,
-            ),
+            self.run_sql(query, args, return_shape=ResultShape.MANY_ONE),
         )
 
     def get_table_type(self, schema: str, table: str) -> Optional[str]:
-        """Get the type of the table (BASE or FOREIGN)"""
+        """Get the type of the table (BASE TABLE, FOREIGN or VIEW)"""
         result = self.run_sql(
             "SELECT table_type FROM information_schema.tables WHERE table_schema = %s"
             " AND table_name = %s",
