@@ -1,8 +1,9 @@
 """
 Extra wrapper code for mount handlers
 """
-from typing import Dict, Any, Optional, TYPE_CHECKING
+from typing import TYPE_CHECKING, Any, Dict, Optional
 
+from splitgraph.engine.utils import unmount_schema
 from splitgraph.exceptions import DataSourceError
 
 if TYPE_CHECKING:
@@ -47,8 +48,7 @@ def mount(
     :param tables: List of tables to mount or their schemas
     """
     # Workaround for circular imports
-    from splitgraph.engine import get_engine
-    from psycopg2.sql import Identifier, SQL
+    from splitgraph.engine.config import get_engine
     from splitgraph.hooks.data_source import get_data_source
     from splitgraph.hooks.data_source.fdw import ForeignDataWrapperDataSource
 
@@ -60,10 +60,7 @@ def mount(
 
     assert issubclass(data_source, ForeignDataWrapperDataSource)
 
-    engine.run_sql(SQL("DROP SCHEMA IF EXISTS {} CASCADE").format(Identifier(mountpoint)))
-    engine.run_sql(
-        SQL("DROP SERVER IF EXISTS {} CASCADE").format(Identifier(mountpoint + "_server"))
-    )
+    unmount_schema(engine, mountpoint)
 
     source = data_source.from_commandline(engine, handler_kwargs)
     source.mount(schema=mountpoint, overwrite=overwrite, tables=tables)
